@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -9,19 +9,15 @@
 #ifndef SQUID_STOREMETAMD5_H
 #define SQUID_STOREMETAMD5_H
 
-/* for inheritance */
 #include "StoreMeta.h"
-/* for MEMPROXY_CLASS() macros */
-#include "MemPool.h"
 /* for STORE_META_KEY_MD5 */
 #include "enums.h"
 
 class StoreMetaMD5 : public StoreMeta
 {
-
-public:
     MEMPROXY_CLASS(StoreMetaMD5);
 
+public:
     char getType() const {return STORE_META_KEY_MD5;}
 
     bool validLength(int) const;
@@ -31,7 +27,5 @@ private:
     static int md5_mismatches;
 };
 
-MEMPROXY_CLASS_INLINE(StoreMetaMD5);
-
 #endif /* SQUID_STOREMETAMD5_H */
 
